@@ -1,7 +1,6 @@
 import unittest
-from unittest.mock import patch
 import logging
-from kinnaird_utils.text.text import strip_special_characters, print_warning
+from kinnaird_utils.text import strip_special_characters
 
 logger = logging.getLogger(__name__)
 
